<?php
/*
Plugin Name: WooCommerce Real-time Notifications for new orders
Description: Tracks your orders in real-time and notifies you when you receive a new order using desktop, sound & tab notification methods.
Version: 1.0.0-mod
Author: Karapet Abrahamyan
Author URI: http://oraksoftware.com/
*/

if (!defined('ABSPATH'))
    die();
	
if(!function_exists('wp_get_current_user'))
    include(ABSPATH . "wp-includes/pluggable.php");

class OrakOrderNotifications
{
	public static $options;
	
	const OPTIONS_PAGE_NAME = 'orak_notification_settings',
		  OPTION_GROUP 	= 'orak_notification_opt_group',
		  OPTION_NAME = 'orak_notification_vars',
		  
		  TEXTDOMAIN = 'orak_notifications';

	public static function Install()
	{
		OrakOrderNotifications::$options = array(
						'use_desktop_notification'		=> 1,
						'use_sound_notification'		=> 1,
						'use_tab_notification'			=> 1,
						'repeat_sound_notification'	    => 0,
						'notification_check_interval'	=> 30,
						'sound_notification_file'		=> 'notification-default.mp3',
						'tab_notification_blink_text'	=> __('* You received a new order *'),
						'notification_logo'				=> 'default-icon2.png',
						'd_notification_title' 		    => __('Great news!'),
						'd_notification_body' 		    => __('You just received a new order! Click to redirect.'),
						'last_checked_id'				=> -1
					);
		add_option(OrakOrderNotifications::OPTION_NAME, OrakOrderNotifications::$options);
	}
	
	public static function Uninstall()
	{
		delete_option(OrakOrderNotifications::OPTION_NAME);
	}
	
	public static function Init()
	{
		if (!current_user_can('manage_woocommerce') ) return;
		
		OrakOrderNotifications::$options = get_option(OrakOrderNotifications::OPTION_NAME);
		
		add_action('wp_ajax_check_orders', array( 'OrakOrderNotifications', 'checkOrders') );
		
		add_action('wp_enqueue_scripts', array( 'OrakOrderNotifications', 'loadScripts'));
		add_action('admin_enqueue_scripts', array( 'OrakOrderNotifications', 'loadScripts'));

		add_action('admin_init', array( 'OrakOrderNotifications', 'registerSettingVars'));
		add_action('admin_menu', array( 'OrakOrderNotifications', 'registerMenusAndLinks'));
		
		register_activation_hook(__FILE__, array('OrakOrderNotifications', 'Install'));
		register_deactivation_hook(__FILE__, array('OrakOrderNotifications', 'Uninstall'));
	}
	
	public static function loadScripts()
	{
		wp_register_script('realtime-notifications-oraksoft', plugins_url( 'realtime-notifications-oraksoft.js' , __FILE__ ));
		wp_enqueue_script('realtime-notifications-oraksoft');
		wp_localize_script('realtime-notifications-oraksoft', 'oraksoft_js_data', array_merge( (array)OrakOrderNotifications::$options, array('site_url' => get_site_url(), 'admin_url' => get_admin_url())));
	}
	
	public static function registerSettingVars()
	{
		register_setting(OrakOrderNotifications::OPTION_GROUP, OrakOrderNotifications::OPTION_NAME);
	}
	
	public static function registerMenusAndLinks()
	{
		add_options_page(__('OrakSoft - WooCommerce Real-time Notification Settings', OrakOrderNotifications::TEXTDOMAIN), __('WooCommerce Real-time Notification Settings', OrakOrderNotifications::TEXTDOMAIN), 'manage_woocommerce', OrakOrderNotifications::OPTIONS_PAGE_NAME, array( 'OrakOrderNotifications', 'AdminPage'));
		
		add_filter("plugin_action_links_".plugin_basename(__FILE__), function($links) { 
			$settings_link = '<a href="options-general.php?page='.OrakOrderNotifications::OPTIONS_PAGE_NAME.'">'.__('Settings', OrakOrderNotifications::TEXTDOMAIN).'</a>'; 
			array_unshift($links, $settings_link); 
			return $links; 
		} );
	}
	
	public static function AdminPage()
	{
		include 'includes/admin-settings.php';
	}
	
	public static function checkOrders() 
	{
		global $woocommerce;
		
		$order_status = 'wc-completed';
		$last_order_query = new WP_Query(array(
						'post_type' => 'shop_order',
						'post_status' => $order_status,
						'meta_key' => '_customer_user',
						'posts_per_page' => '1',
						'orderby' => 'date',
						'order' => 'DESC'
					));

		$customer_order = $last_order_query->posts;
		
		$order = new WC_Order( current( $customer_order ) );
		// $order->populate(current($customer_order));
		$orderdata = (array) $order;

		$option_data = get_option(OrakOrderNotifications::OPTION_NAME);
		$last_order_cookie = isset($_COOKIE['last_order_oraksoft_notifier']) && (int)$_COOKIE['last_order_oraksoft_notifier'] > 0 ? (int)$_COOKIE['last_order_oraksoft_notifier'] : $option_data['last_checked_id'];
		$order_id = $order->get_id();
		setcookie("last_order_oraksoft_notifier", $order_id, time()+3600);
		
		// vlshop_woocommerce_error_log( '---', 'notification' );
		// vlshop_woocommerce_error_log( '$orderdata: ' . print_r( $orderdata, true ), 'notification' );
		if((int)$order_id == $last_order_cookie || $last_order_cookie == -1) {
			// vlshop_woocommerce_error_log( 'No change in Order', 'notification' );
			// vlshop_woocommerce_error_log( '$order_id: ' . $order_id, 'notification' );
			// vlshop_woocommerce_error_log( '$last_order_cookie: ' . $last_order_cookie, 'notification' );
			echo -1;
		} else if((int)$order_id > $last_order_cookie) {

			vlshop_woocommerce_error_log( 'Change in Order detected', 'notification' );
			vlshop_woocommerce_error_log( '$order_id: ' . $order_id, 'notification' );
			vlshop_woocommerce_error_log( '$last_order_cookie: ' . $last_order_cookie, 'notification' );
			vlshop_woocommerce_error_log( '---', 'notification' );

			$option_data['last_checked_id'] = $order_id;
			update_option(OrakOrderNotifications::OPTION_NAME, $option_data);

			echo $order_id; 

			// Allow Theme and Plugin developers to extend this notification action
			do_action( 'orak_notification_extend', $order_id, $orderdata );

		}
		die();
	}
}


OrakOrderNotifications::Init();
?>